@@ -111,7 +111,6 @@ class YNotebook(YBaseDoc):
                     "id": str(uuid4()),
                 }
             ]
-        # workaround until ypy is fixed: https://github.com/davidbrochart/ypy-websocket/pull/9
         with self._ydoc.begin_transaction() as t:
             # clear document
             cells_len = len(self._ycells)
@@ -126,6 +125,8 @@ class YNotebook(YBaseDoc):
             ycells = []
             for cell in nb["cells"]:
                 cell["source"] = Y.YText(cell["source"])
+                if "id" not in cell:
+                    cell["id"] = str(uuid4())
                 if "outputs" in cell:
                     cell["outputs"] = Y.YArray(cell["outputs"])
                 ycell = Y.YMap(cell)
